<?php

class Soledad_Social_Counter extends WP_Widget {

	/**
	 * Sets up the widgets name etc
	 */
	public function __construct() {
		$widget_ops = array(
			'classname'   => 'penci_social_counter',
			'description' => 'Show social counter data.',
		);
		parent::__construct( 'penci_social_counter', '.Soledad Social Counter', $widget_ops );
	}

	/**
	 * Outputs the content of the widget
	 *
	 * @param array $args
	 * @param array $instance
	 */
	public function widget( $args, $instance ) {
		$title        = isset( $instance['title'] ) ? $instance['title'] : '';
		$title        = apply_filters( 'widget_title', $title );
		$css_class    = 'penci-block-vc penci-social-counter';
		$social_style = isset( $instance['style'] ) && $instance['style'] ? $instance['style'] : 's1';
		$social_col   = isset( $instance['columns'] ) && $instance['columns'] ? $instance['columns'] : '1';
		$classess     = array();
		$classess[]   = 'penci-socialCT-wrap';
		$classess[]   = 'columns-' . esc_attr( $social_col );
		$classess[]   = 'penci-socialCT-' . esc_attr( $social_style );
		$classess[]   = 's8' == $social_style ? 'penci-social-textcolored' : 'penci-normal-textcolored';

		echo $args['before_widget'];
		if ( $title ) {
			echo $args['before_title'] . $title . $args['after_title'];
		}

		?>
        <div class="<?php echo esc_attr( $css_class ); ?>">
            <div class="penci-block_content">
				<?php
				$socials = array(
					'facebook',
					'twitter',
					'youtube',
					'instagram',
					'pinterest',
					'flickr',
					'vimeo',
					'soundcloud',
					'behance ',
					'vk',
					'twitch',
					'rss',
				);

				$error = array();

				$has_data = false;

				echo '<div class="' . implode( ' ', $classess ) . '">';

				foreach ( $socials as $social ) {


					if ( empty( $instance[ $social ] ) ) {
						continue;
					}

					$social_info = \PENCI_FW_Social_Counter::get_social_counter( $social );

					$social_info_name = isset( $social_info['name'] ) ? $social_info['name'] : '';

					if ( ! $social_info || ! $social_info_name ) {
						continue;
					}

					$has_data = true;

					$target = 'target="_blank"';
					if ( ! get_theme_mod( 'penci_dis_noopener' ) ) {
						$target .= ' rel=noopener"';
					}

					$count         = ! empty( $social_info['count'] ) ? $social_info['count'] : 0;
					$count         = \PENCI_FW_Social_Counter::format_followers( $count );

					?>
                    <div class="penci-socialCT-item penci-social-<?php echo $social . ( ! $social_info['count'] ? ' penci-socialCT-empty' : '' ); ?>">
                        <a class="penci-social-content"
                           href="<?php echo esc_url( $social_info['url'] ); ?>" <?php echo $target; ?>>
						<span>
						<?php
						if ( 's1' == $social_style ) {
							echo $social_info['icon'];
							echo '<span class="penci-social-name">' . $social_info['title'] . '</span>';
							echo '<span class="penci-social-button">';

							if ( $count ) {
								echo '<span>' . $count . '</span>';
							}

							echo $social_info['text_btn'];
							echo '</span>';
						} elseif ( 's2' == $social_style ) {
							echo $social_info['icon'];
							echo '<span class="penci-social-name">' . $social_info['title'] . '</span>';
						} elseif ( 's3' == $social_style || 's5' == $social_style || 's6' == $social_style ) {
							echo $social_info['icon'];
						} else {
							echo $social_info['icon'];
							if ( $count ) {
								echo '<span class="penci-social-number">' . $count . '</span>';
							}
							if ( isset( $social_info['text_below'] ) && $social_info['text_below'] ) {
								echo '<span class="penci-social-info-text">' . $social_info['text_below'] . '</span>';
							}
						}
						?>
						</span>
                        </a>
						<?php
						if ( 's6' == $social_style && isset( $social_info['count'] ) ) {
							echo '<span class="penci-social-number">' . $count . '</span>';
							if ( isset( $social_info['text'] ) ) {
								echo '<span class="penci-social-info-text">' . $social_info['text'] . '</span>';
							}
						}
						?>
                    </div>
					<?php

					if ( ! empty( $social_info['error'] ) ) {
						$error[] = $social_info['error'];
					}
				}

				echo '</div>';

				if ( ! $has_data ) {
					$error[] = esc_html__( 'Please go to Dashboad > Soledad > Social Counter, press Social Counter tab then insert social information you want show', 'soledad' );
				}
				?>
            </div>
        </div>
		<?php
		echo $args['after_widget'];
	}

	/**
	 * Outputs the options form on admin
	 *
	 * @param array $instance The widget options
	 */
	public function form( $instance ) {
		$title        = ! empty( $instance['title'] ) ? $instance['title'] : esc_html__( '.Soledad Social Counter', 'soledad' );
		$social_lists = $this->social_lists();
		$style        = ! empty( $instance['style'] ) ? $instance['style'] : 's1';
		$columns      = ! empty( $instance['columns'] ) ? $instance['columns'] : '1';
		?>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"><?php esc_attr_e( 'Title:', 'soledad' ); ?></label>
            <input class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'title' ) ); ?>"
                   name="<?php echo esc_attr( $this->get_field_name( 'title' ) ); ?>" type="text"
                   value="<?php echo esc_attr( $title ); ?>">
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>">Select Style:</label>
            <select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'style' ) ); ?>"
                    name="<?php echo esc_attr( $this->get_field_name( 'style' ) ); ?>">
                <option value="s1" <?php selected( $style, 's1' ); ?>><?php echo esc_html__( 'Style 1', 'soledad' ); ?></option>
                <option value="s2" <?php selected( $style, 's2' ); ?>><?php echo esc_html__( 'Style 2', 'soledad' ); ?></option>
                <option value="s3" <?php selected( $style, 's3' ); ?>><?php echo esc_html__( 'Style 3', 'soledad' ); ?></option>
                <option value="s4" <?php selected( $style, 's4' ); ?>><?php echo esc_html__( 'Style 4', 'soledad' ); ?></option>
                <option value="s5" <?php selected( $style, 's5' ); ?>><?php echo esc_html__( 'Style 5', 'soledad' ); ?></option>
                <option value="s6" <?php selected( $style, 's6' ); ?>><?php echo esc_html__( 'Style 6', 'soledad' ); ?></option>
                <option value="s7" <?php selected( $style, 's7' ); ?>><?php echo esc_html__( 'Style 7', 'soledad' ); ?></option>
                <option value="s8" <?php selected( $style, 's8' ); ?>><?php echo esc_html__( 'Style 8', 'soledad' ); ?></option>
                <option value="s9" <?php selected( $style, 's9' ); ?>><?php echo esc_html__( 'Style 9', 'soledad' ); ?></option>
            </select>
        </p>
        <p>
            <label for="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>">Select Columns:</label>
            <select class="widefat" id="<?php echo esc_attr( $this->get_field_id( 'columns' ) ); ?>"
                    name="<?php echo esc_attr( $this->get_field_name( 'columns' ) ); ?>">
                <option value="1" <?php selected( $columns, '1' ); ?>><?php echo esc_html__( '1 Column', 'soledad' ); ?></option>
                <option value="2" <?php selected( $columns, '2' ); ?>><?php echo esc_html__( '2 Columns', 'soledad' ); ?></option>
                <option value="3" <?php selected( $columns, '3' ); ?>><?php echo esc_html__( '3 Columns', 'soledad' ); ?></option>
                <option value="4" <?php selected( $columns, '4' ); ?>><?php echo esc_html__( '4 Columns', 'soledad' ); ?></option>
                <option value="5" <?php selected( $columns, '5' ); ?>><?php echo esc_html__( '5 Columns', 'soledad' ); ?></option>
                <option value="6" <?php selected( $columns, '6' ); ?>><?php echo esc_html__( '6 Columns', 'soledad' ); ?></option>
            </select>
        </p>
		<?php
		foreach ( $social_lists as $social => $social_info ) {
			$checked = isset( $instance[ $social ] ) ? (bool) $instance[ $social ] : false;
			?>

            <p>
                <input class="checkbox" id="<?php echo esc_attr( $this->get_field_id( $social ) ); ?>"
                       name="<?php echo esc_attr( $this->get_field_name( $social ) ); ?>"
                       type="checkbox" <?php checked( $checked ); ?> />
                <label for="<?php echo esc_attr( $this->get_field_id( $social ) ); ?>"><?php echo esc_attr( $social_info['label'] ); ?></label>
            </p>

			<?php

		}
	}

	/**
	 * Outputs the social array listing
	 *
	 */
	public function social_lists() {
		return array(
			'facebook'   => array( 'label' => __( 'Facebook', 'soledad' ), 'default' => 'yes' ),
			'twitter'    => array( 'label' => __( 'Twitter', 'soledad' ), 'default' => 'yes' ),
			'youtube'    => array( 'label' => __( 'Youtube', 'soledad' ), 'default' => 'yes' ),
			'instagram'  => array( 'label' => __( 'Instagram', 'soledad' ), 'default' => 'yes' ),
			'pinterest'  => array( 'label' => __( 'Pinterest', 'soledad' ), 'default' => '' ),
			'flickr'     => array( 'label' => __( 'Flickr', 'soledad' ), 'default' => '' ),
			'vimeo'      => array( 'label' => __( 'Vimeo', 'soledad' ), 'default' => '' ),
			'soundcloud' => array( 'label' => __( 'SoundCloud', 'soledad' ), 'default' => '' ),
			'behance '   => array( 'label' => __( 'Behance', 'soledad' ), 'default' => '' ),
			'vk'         => array( 'label' => __( 'VK', 'soledad' ), 'default' => '' ),
			'twitch'     => array( 'label' => __( 'Twitch', 'soledad' ), 'default' => '' ),
			'rss'        => array( 'label' => __( 'RSS', 'soledad' ), 'default' => '' ),
		);
	}

	/**
	 * Processing widget options on save
	 *
	 * @param array $new_instance The new options
	 * @param array $old_instance The previous options
	 *
	 * @return array
	 */
	public function update( $new_instance, $old_instance ) {
		$instance            = $old_instance;
		$instance['title']   = ( ! empty( $new_instance['title'] ) ) ? sanitize_text_field( $new_instance['title'] ) : '';
		$instance['style']   = ( ! empty( $new_instance['style'] ) ) ? sanitize_text_field( $new_instance['style'] ) : 's1';
		$instance['columns'] = ( ! empty( $new_instance['columns'] ) ) ? sanitize_text_field( $new_instance['columns'] ) : '1';

		foreach ( $this->social_lists() as $social => $social_info ) {
			$instance[ $social ] = ( ! empty( $new_instance[ $social ] ) ) ? 1 : 0;
		}

		return $instance;
	}
}

// register widget
function penci_register_social_counter_widget() {
	register_widget( 'Soledad_Social_Counter' );
}

add_action( 'widgets_init', 'penci_register_social_counter_widget' );

